@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from .literals import (
     ArrayJobDependencyType,
@@ -25,6 +25,7 @@ from .literals import (
     DeviceCgroupPermissionType,
     EFSAuthorizationConfigIAMType,
     EFSTransitEncryptionType,
+    JobDefinitionTypeType,
     JobStatusType,
     JQStateType,
     JQStatusType,
@@ -46,6 +47,7 @@ __all__ = (
     "ArrayPropertiesTypeDef",
     "AttemptContainerDetailTypeDef",
     "AttemptDetailTypeDef",
+    "CancelJobRequestRequestTypeDef",
     "ComputeEnvironmentDetailTypeDef",
     "ComputeEnvironmentOrderTypeDef",
     "ComputeResourceTypeDef",
@@ -54,11 +56,20 @@ __all__ = (
     "ContainerOverridesTypeDef",
     "ContainerPropertiesTypeDef",
     "ContainerSummaryTypeDef",
+    "CreateComputeEnvironmentRequestRequestTypeDef",
     "CreateComputeEnvironmentResponseTypeDef",
+    "CreateJobQueueRequestRequestTypeDef",
     "CreateJobQueueResponseTypeDef",
+    "DeleteComputeEnvironmentRequestRequestTypeDef",
+    "DeleteJobQueueRequestRequestTypeDef",
+    "DeregisterJobDefinitionRequestRequestTypeDef",
+    "DescribeComputeEnvironmentsRequestRequestTypeDef",
     "DescribeComputeEnvironmentsResponseTypeDef",
+    "DescribeJobDefinitionsRequestRequestTypeDef",
     "DescribeJobDefinitionsResponseTypeDef",
+    "DescribeJobQueuesRequestRequestTypeDef",
     "DescribeJobQueuesResponseTypeDef",
+    "DescribeJobsRequestRequestTypeDef",
     "DescribeJobsResponseTypeDef",
     "DeviceTypeDef",
     "EFSAuthorizationConfigTypeDef",
@@ -76,7 +87,9 @@ __all__ = (
     "KeyValuePairTypeDef",
     "LaunchTemplateSpecificationTypeDef",
     "LinuxParametersTypeDef",
+    "ListJobsRequestRequestTypeDef",
     "ListJobsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "LogConfigurationTypeDef",
     "MountPointTypeDef",
@@ -89,14 +102,22 @@ __all__ = (
     "NodePropertyOverrideTypeDef",
     "NodeRangePropertyTypeDef",
     "PaginatorConfigTypeDef",
+    "RegisterJobDefinitionRequestRequestTypeDef",
     "RegisterJobDefinitionResponseTypeDef",
     "ResourceRequirementTypeDef",
+    "ResponseMetadataTypeDef",
     "RetryStrategyTypeDef",
     "SecretTypeDef",
+    "SubmitJobRequestRequestTypeDef",
     "SubmitJobResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "TerminateJobRequestRequestTypeDef",
     "TmpfsTypeDef",
     "UlimitTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateComputeEnvironmentRequestRequestTypeDef",
     "UpdateComputeEnvironmentResponseTypeDef",
+    "UpdateJobQueueRequestRequestTypeDef",
     "UpdateJobQueueResponseTypeDef",
     "VolumeTypeDef",
 )
@@ -152,6 +173,14 @@ AttemptDetailTypeDef = TypedDict(
     total=False,
 )
 
+CancelJobRequestRequestTypeDef = TypedDict(
+    "CancelJobRequestRequestTypeDef",
+    {
+        "jobId": str,
+        "reason": str,
+    },
+)
+
 _RequiredComputeEnvironmentDetailTypeDef = TypedDict(
     "_RequiredComputeEnvironmentDetailTypeDef",
     {
@@ -317,28 +346,122 @@ ContainerSummaryTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCreateComputeEnvironmentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateComputeEnvironmentRequestRequestTypeDef",
+    {
+        "computeEnvironmentName": str,
+        "type": CETypeType,
+    },
+)
+_OptionalCreateComputeEnvironmentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateComputeEnvironmentRequestRequestTypeDef",
+    {
+        "state": CEStateType,
+        "computeResources": "ComputeResourceTypeDef",
+        "serviceRole": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateComputeEnvironmentRequestRequestTypeDef(
+    _RequiredCreateComputeEnvironmentRequestRequestTypeDef,
+    _OptionalCreateComputeEnvironmentRequestRequestTypeDef,
+):
+    pass
+
+
 CreateComputeEnvironmentResponseTypeDef = TypedDict(
     "CreateComputeEnvironmentResponseTypeDef",
     {
         "computeEnvironmentName": str,
         "computeEnvironmentArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateJobQueueRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateJobQueueRequestRequestTypeDef",
+    {
+        "jobQueueName": str,
+        "priority": int,
+        "computeEnvironmentOrder": List["ComputeEnvironmentOrderTypeDef"],
+    },
+)
+_OptionalCreateJobQueueRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateJobQueueRequestRequestTypeDef",
+    {
+        "state": JQStateType,
+        "tags": Dict[str, str],
     },
     total=False,
 )
 
+
+class CreateJobQueueRequestRequestTypeDef(
+    _RequiredCreateJobQueueRequestRequestTypeDef, _OptionalCreateJobQueueRequestRequestTypeDef
+):
+    pass
+
+
 CreateJobQueueResponseTypeDef = TypedDict(
     "CreateJobQueueResponseTypeDef",
     {
         "jobQueueName": str,
         "jobQueueArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+DeleteComputeEnvironmentRequestRequestTypeDef = TypedDict(
+    "DeleteComputeEnvironmentRequestRequestTypeDef",
+    {
+        "computeEnvironment": str,
+    },
+)
+
+DeleteJobQueueRequestRequestTypeDef = TypedDict(
+    "DeleteJobQueueRequestRequestTypeDef",
+    {
+        "jobQueue": str,
+    },
+)
+
+DeregisterJobDefinitionRequestRequestTypeDef = TypedDict(
+    "DeregisterJobDefinitionRequestRequestTypeDef",
+    {
+        "jobDefinition": str,
+    },
+)
+
+DescribeComputeEnvironmentsRequestRequestTypeDef = TypedDict(
+    "DescribeComputeEnvironmentsRequestRequestTypeDef",
+    {
+        "computeEnvironments": List[str],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 DescribeComputeEnvironmentsResponseTypeDef = TypedDict(
     "DescribeComputeEnvironmentsResponseTypeDef",
     {
         "computeEnvironments": List["ComputeEnvironmentDetailTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeJobDefinitionsRequestRequestTypeDef = TypedDict(
+    "DescribeJobDefinitionsRequestRequestTypeDef",
+    {
+        "jobDefinitions": List[str],
+        "maxResults": int,
+        "jobDefinitionName": str,
+        "status": str,
+        "nextToken": str,
     },
     total=False,
 )
@@ -348,6 +471,16 @@ DescribeJobDefinitionsResponseTypeDef = TypedDict(
     {
         "jobDefinitions": List["JobDefinitionTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeJobQueuesRequestRequestTypeDef = TypedDict(
+    "DescribeJobQueuesRequestRequestTypeDef",
+    {
+        "jobQueues": List[str],
+        "maxResults": int,
+        "nextToken": str,
     },
     total=False,
 )
@@ -357,16 +490,23 @@ DescribeJobQueuesResponseTypeDef = TypedDict(
     {
         "jobQueues": List["JobQueueDetailTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeJobsRequestRequestTypeDef = TypedDict(
+    "DescribeJobsRequestRequestTypeDef",
+    {
+        "jobs": List[str],
     },
-    total=False,
 )
 
 DescribeJobsResponseTypeDef = TypedDict(
     "DescribeJobsResponseTypeDef",
     {
         "jobs": List["JobDetailTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredDeviceTypeDef = TypedDict(
@@ -649,31 +789,41 @@ LinuxParametersTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListJobsResponseTypeDef = TypedDict(
-    "_RequiredListJobsResponseTypeDef",
-    {
-        "jobSummaryList": List["JobSummaryTypeDef"],
-    },
-)
-_OptionalListJobsResponseTypeDef = TypedDict(
-    "_OptionalListJobsResponseTypeDef",
+ListJobsRequestRequestTypeDef = TypedDict(
+    "ListJobsRequestRequestTypeDef",
     {
+        "jobQueue": str,
+        "arrayJobId": str,
+        "multiNodeJobId": str,
+        "jobStatus": JobStatusType,
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
+ListJobsResponseTypeDef = TypedDict(
+    "ListJobsResponseTypeDef",
+    {
+        "jobSummaryList": List["JobSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
 
-class ListJobsResponseTypeDef(_RequiredListJobsResponseTypeDef, _OptionalListJobsResponseTypeDef):
-    pass
-
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredLogConfigurationTypeDef = TypedDict(
@@ -813,12 +963,43 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredRegisterJobDefinitionRequestRequestTypeDef = TypedDict(
+    "_RequiredRegisterJobDefinitionRequestRequestTypeDef",
+    {
+        "jobDefinitionName": str,
+        "type": JobDefinitionTypeType,
+    },
+)
+_OptionalRegisterJobDefinitionRequestRequestTypeDef = TypedDict(
+    "_OptionalRegisterJobDefinitionRequestRequestTypeDef",
+    {
+        "parameters": Dict[str, str],
+        "containerProperties": "ContainerPropertiesTypeDef",
+        "nodeProperties": "NodePropertiesTypeDef",
+        "retryStrategy": "RetryStrategyTypeDef",
+        "propagateTags": bool,
+        "timeout": "JobTimeoutTypeDef",
+        "tags": Dict[str, str],
+        "platformCapabilities": List[PlatformCapabilityType],
+    },
+    total=False,
+)
+
+
+class RegisterJobDefinitionRequestRequestTypeDef(
+    _RequiredRegisterJobDefinitionRequestRequestTypeDef,
+    _OptionalRegisterJobDefinitionRequestRequestTypeDef,
+):
+    pass
+
+
 RegisterJobDefinitionResponseTypeDef = TypedDict(
     "RegisterJobDefinitionResponseTypeDef",
     {
         "jobDefinitionName": str,
         "jobDefinitionArn": str,
         "revision": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -830,6 +1011,17 @@ ResourceRequirementTypeDef = TypedDict(
     },
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 RetryStrategyTypeDef = TypedDict(
     "RetryStrategyTypeDef",
     {
@@ -847,28 +1039,63 @@ SecretTypeDef = TypedDict(
     },
 )
 
-_RequiredSubmitJobResponseTypeDef = TypedDict(
-    "_RequiredSubmitJobResponseTypeDef",
+_RequiredSubmitJobRequestRequestTypeDef = TypedDict(
+    "_RequiredSubmitJobRequestRequestTypeDef",
     {
         "jobName": str,
-        "jobId": str,
+        "jobQueue": str,
+        "jobDefinition": str,
     },
 )
-_OptionalSubmitJobResponseTypeDef = TypedDict(
-    "_OptionalSubmitJobResponseTypeDef",
+_OptionalSubmitJobRequestRequestTypeDef = TypedDict(
+    "_OptionalSubmitJobRequestRequestTypeDef",
     {
-        "jobArn": str,
+        "arrayProperties": "ArrayPropertiesTypeDef",
+        "dependsOn": List["JobDependencyTypeDef"],
+        "parameters": Dict[str, str],
+        "containerOverrides": "ContainerOverridesTypeDef",
+        "nodeOverrides": "NodeOverridesTypeDef",
+        "retryStrategy": "RetryStrategyTypeDef",
+        "propagateTags": bool,
+        "timeout": "JobTimeoutTypeDef",
+        "tags": Dict[str, str],
     },
     total=False,
 )
 
 
-class SubmitJobResponseTypeDef(
-    _RequiredSubmitJobResponseTypeDef, _OptionalSubmitJobResponseTypeDef
+class SubmitJobRequestRequestTypeDef(
+    _RequiredSubmitJobRequestRequestTypeDef, _OptionalSubmitJobRequestRequestTypeDef
 ):
     pass
 
 
+SubmitJobResponseTypeDef = TypedDict(
+    "SubmitJobResponseTypeDef",
+    {
+        "jobArn": str,
+        "jobName": str,
+        "jobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Dict[str, str],
+    },
+)
+
+TerminateJobRequestRequestTypeDef = TypedDict(
+    "TerminateJobRequestRequestTypeDef",
+    {
+        "jobId": str,
+        "reason": str,
+    },
+)
+
 _RequiredTmpfsTypeDef = TypedDict(
     "_RequiredTmpfsTypeDef",
     {
@@ -898,22 +1125,77 @@ UlimitTypeDef = TypedDict(
     },
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
+_RequiredUpdateComputeEnvironmentRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateComputeEnvironmentRequestRequestTypeDef",
+    {
+        "computeEnvironment": str,
+    },
+)
+_OptionalUpdateComputeEnvironmentRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateComputeEnvironmentRequestRequestTypeDef",
+    {
+        "state": CEStateType,
+        "computeResources": "ComputeResourceUpdateTypeDef",
+        "serviceRole": str,
+    },
+    total=False,
+)
+
+
+class UpdateComputeEnvironmentRequestRequestTypeDef(
+    _RequiredUpdateComputeEnvironmentRequestRequestTypeDef,
+    _OptionalUpdateComputeEnvironmentRequestRequestTypeDef,
+):
+    pass
+
+
 UpdateComputeEnvironmentResponseTypeDef = TypedDict(
     "UpdateComputeEnvironmentResponseTypeDef",
     {
         "computeEnvironmentName": str,
         "computeEnvironmentArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateJobQueueRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateJobQueueRequestRequestTypeDef",
+    {
+        "jobQueue": str,
+    },
+)
+_OptionalUpdateJobQueueRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateJobQueueRequestRequestTypeDef",
+    {
+        "state": JQStateType,
+        "priority": int,
+        "computeEnvironmentOrder": List["ComputeEnvironmentOrderTypeDef"],
     },
     total=False,
 )
 
+
+class UpdateJobQueueRequestRequestTypeDef(
+    _RequiredUpdateJobQueueRequestRequestTypeDef, _OptionalUpdateJobQueueRequestRequestTypeDef
+):
+    pass
+
+
 UpdateJobQueueResponseTypeDef = TypedDict(
     "UpdateJobQueueResponseTypeDef",
     {
         "jobQueueName": str,
         "jobQueueArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 VolumeTypeDef = TypedDict(
